==> blesta-5.10.2.zip: blesta/language/uk_ua/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Пакетний процес';
$lang['AdminBilling.batch.field_passphrase'] = 'Парольна фраза';
$lang['AdminBilling.batch.text_description'] = 'Введіть пароль, щоб вручну обробити всі інвойси, заплановані до автоматичного списання з локально збереженого платіжного рахунку.';
$lang['AdminBilling.batch.no_passphrase'] = 'Ручна пакетна обробка не ввімкнена.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Партія';
$lang['AdminBilling.batch.page_title'] = 'Білінгова партія';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Позначка надрукована';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Друк';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Дата відправлення';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Дата сплати';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Дата виставлення рахунку';
$lang['AdminBilling.printqueue.heading_due'] = 'Належить';
$lang['AdminBilling.printqueue.heading_paid'] = 'Оплачено';
$lang['AdminBilling.printqueue.heading_amount'] = 'Сума';
$lang['AdminBilling.printqueue.heading_client'] = 'Клієнт №';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'У черзі на друк немає рахунків-фактур.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Раніше роздрукованих рахунків немає.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Черга на друк';
$lang['AdminBilling.printqueue.category_printed'] = 'Раніше надруковано';
$lang['AdminBilling.printqueue.category_to_print'] = 'Друк';
$lang['AdminBilling.printqueue.page_title'] = 'Черга на друк рахунків';
$lang['AdminBilling.invoices.text_edit'] = 'Редагувати';
$lang['AdminBilling.invoices.applied_no_results'] = 'До цього інвойсу не застосовано жодних транзакцій.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Параметри';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Нанесено на';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Застосовано';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Тип платежу';
$lang['AdminBilling.transactions.applied_no_results'] = 'Ця операція не була застосована до жодного інвойсу.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Нанесено на';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.transactions.no_results'] = 'Транзакцій з таким статусом немає.';
$lang['AdminBilling.transactions.option_edit'] = 'Редагувати';
$lang['AdminBilling.transactions.category_returned'] = 'Повернуто';
$lang['AdminBilling.transactions.category_refunded'] = 'Відшкодовано';
$lang['AdminBilling.transactions.category_pending'] = 'На розгляді';
$lang['AdminBilling.transactions.category_error'] = 'Помилка.';
$lang['AdminBilling.transactions.category_voided'] = 'Анульовано';
$lang['AdminBilling.transactions.category_declined'] = 'Відхилено';
$lang['AdminBilling.transactions.category_approved'] = 'Затверджено';
$lang['AdminBilling.transactions.heading_options'] = 'Параметри';
$lang['AdminBilling.transactions.heading_date'] = 'Дата';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Посилання #';
$lang['AdminBilling.transactions.heading_number'] = 'Номер';
$lang['AdminBilling.transactions.heading_applied'] = 'Застосовано';
$lang['AdminBilling.transactions.heading_credit'] = 'В ролях';
$lang['AdminBilling.transactions.heading_amount'] = 'Сума';
$lang['AdminBilling.transactions.heading_type'] = 'Тип';
$lang['AdminBilling.transactions.heading_client'] = 'Клієнт №';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Транзакції';
$lang['AdminBilling.transactions.page_title'] = 'Білінгові операції';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Причина скасування: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Ця послуга не має реквізитів.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Надіслати';
$lang['AdminBilling.services.action.field_client'] = 'Клієнт:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push до клієнта';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Не скасовувати';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Конкретна дата';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Кінець терміну';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Скасування розкладу';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Сервісів з таким статусом немає.';
$lang['AdminBilling.services.text_never'] = 'Ніколи.';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Заплановано';
$lang['AdminBilling.services.category_in_review'] = 'В огляді';
$lang['AdminBilling.services.category_pending'] = 'На розгляді';
$lang['AdminBilling.services.category_suspended'] = 'Призупинено';
$lang['AdminBilling.services.category_canceled'] = 'Скасовано';
$lang['AdminBilling.services.category_active'] = 'Активний';
$lang['AdminBilling.services.confirm_delete'] = 'Ви впевнені, що хочете видалити цю послугу?';
$lang['AdminBilling.services.option_delete'] = 'Видалити';
$lang['AdminBilling.services.option_manage'] = 'Керувати';
$lang['AdminBilling.services.heading_options'] = 'Параметри';
$lang['AdminBilling.services.heading_datecanceled'] = 'Дата скасована';
$lang['AdminBilling.services.heading_datesuspended'] = 'Дата призупинена';
$lang['AdminBilling.services.heading_daterenews'] = 'Поновлення дати';
$lang['AdminBilling.services.heading_dateadded'] = 'Дата додавання';
$lang['AdminBilling.services.heading_term'] = 'Термін';
$lang['AdminBilling.services.heading_label'] = 'Етикетка';
$lang['AdminBilling.services.heading_package'] = 'Пакет';
$lang['AdminBilling.services.heading_client'] = 'Клієнт №';
$lang['AdminBilling.services.boxtitle_services'] = 'Послуги';
$lang['AdminBilling.services.page_title'] = 'Білінгові послуги';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'З цією ціною не пов\'язано жодних рахунків-фактур.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Вигляд';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Параметри';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Дата виставлення рахунку';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Оплачено';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.quotations.no_results'] = 'Котирувань з таким статусом немає.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Ви впевнені, що хочете затвердити цю цитату?';
$lang['AdminBilling.quotations.option_approve'] = 'Затвердити';
$lang['AdminBilling.quotations.option_invoice'] = 'Створити рахунок-фактуру';
$lang['AdminBilling.quotations.option_view'] = 'Вигляд';
$lang['AdminBilling.quotations.option_edit'] = 'Редагувати';
$lang['AdminBilling.quotations.heading_options'] = 'Параметри';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Термін придатності';
$lang['AdminBilling.quotations.heading_date_created'] = 'Дата створення';
$lang['AdminBilling.quotations.heading_total'] = 'Сума';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Проміжний підсумок';
$lang['AdminBilling.quotations.heading_staff'] = 'Цитується';
$lang['AdminBilling.quotations.heading_title'] = 'Назва';
$lang['AdminBilling.quotations.heading_client'] = 'Клієнт №';
$lang['AdminBilling.quotations.heading_quotation'] = 'Цитата #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Цитати';
$lang['AdminBilling.quotations.page_title'] = 'Котирування рахунків';
$lang['AdminBilling.invoices.no_results'] = 'Інвойсів з таким статусом немає.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s разів';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s років';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s місяців';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s тижнів';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s днів';
$lang['AdminBilling.invoices.term_year'] = '%1$ рік';
$lang['AdminBilling.invoices.term_month'] = '%1$s місяць';
$lang['AdminBilling.invoices.term_week'] = '%1$ тиждень';
$lang['AdminBilling.invoices.term_day'] = '%1$ день';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s + податок';
$lang['AdminBilling.invoices.option_pay'] = 'Заплати';
$lang['AdminBilling.invoices.option_view'] = 'Вигляд';
$lang['AdminBilling.invoices.option_edit'] = 'Редагувати';
$lang['AdminBilling.invoices.category_recurring'] = 'Повторюється';
$lang['AdminBilling.invoices.category_pending'] = 'На розгляді';
$lang['AdminBilling.invoices.category_pastdue'] = 'Прострочена заборгованість';
$lang['AdminBilling.invoices.category_voided'] = 'Анульовано';
$lang['AdminBilling.invoices.category_closed'] = 'Закрито.';
$lang['AdminBilling.invoices.category_drafts'] = 'Чернетки';
$lang['AdminBilling.invoices.category_open'] = 'Відчинено';
$lang['AdminBilling.invoices.heading_count'] = 'Граф.';
$lang['AdminBilling.invoices.heading_duration'] = 'Тривалість';
$lang['AdminBilling.invoices.heading_term'] = 'Термін';
$lang['AdminBilling.invoices.heading_options'] = 'Параметри';
$lang['AdminBilling.invoices.heading_datedue'] = 'Дата сплати';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Дата виставлення рахунку';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Дата закрита';
$lang['AdminBilling.invoices.heading_due'] = 'Належить';
$lang['AdminBilling.invoices.heading_paid'] = 'Оплачено';
$lang['AdminBilling.invoices.heading_amount'] = 'Сума';
$lang['AdminBilling.invoices.heading_client'] = 'Клієнт №';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Повторювані #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Рахунки-фактури';
$lang['AdminBilling.invoices.page_title'] = 'Виставлення рахунків-фактур';
$lang['AdminBilling.managewidgets.text_author'] = 'Автор:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Перетягніть віджети справа наліво, щоб додати їх до огляду рахунків, або зліва направо, щоб видалити.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Виберіть макет нижче, щоб налаштувати огляд рахунків.';
$lang['AdminBilling.index.action_batch'] = 'Товари, що очікують на партію';
$lang['AdminBilling.index.action_printqueue'] = 'Елементи, що очікують на друк';
$lang['AdminBilling.index.no_actions'] = 'На розгляді немає жодних питань щодо дій.';
$lang['AdminBilling.index.heading_actions'] = 'Пункти дій';
$lang['AdminBilling.index.customize_dashboard'] = 'Налаштувати огляд';
$lang['AdminBilling.index.manage_widgets'] = 'Керування віджетами';
$lang['AdminBilling.index.page_title'] = 'Огляд виставлення рахунків';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Запланована дата скасування не повинна бути в минулому.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Введена парольна фраза є невірною.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Не було відібрано жодного інвойсу.';
$lang['AdminBilling.!success.services_pushed'] = 'Обрані послуги були успішно продані новому клієнту.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Вибрані послуги більше не планується скасовувати.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Вибрані послуги були успішно скасовані за розкладом.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Вибрані інвойси позначені як надруковані.';

==> blesta-5.11.4.zip: blesta/language/uk_ua/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Пакетний процес';
$lang['AdminBilling.batch.field_passphrase'] = 'Парольна фраза';
$lang['AdminBilling.batch.text_description'] = 'Введіть пароль, щоб вручну обробити всі інвойси, заплановані до автоматичного списання з локально збереженого платіжного рахунку.';
$lang['AdminBilling.batch.no_passphrase'] = 'Ручна пакетна обробка не ввімкнена.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Партія';
$lang['AdminBilling.batch.page_title'] = 'Білінгова партія';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Позначка надрукована';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Друк';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Дата відправлення';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Дата сплати';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Дата виставлення рахунку';
$lang['AdminBilling.printqueue.heading_due'] = 'Належить';
$lang['AdminBilling.printqueue.heading_paid'] = 'Оплачено';
$lang['AdminBilling.printqueue.heading_amount'] = 'Сума';
$lang['AdminBilling.printqueue.heading_client'] = 'Клієнт №';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'У черзі на друк немає рахунків-фактур.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Раніше роздрукованих рахунків немає.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Черга на друк';
$lang['AdminBilling.printqueue.category_printed'] = 'Раніше надруковано';
$lang['AdminBilling.printqueue.category_to_print'] = 'Друк';
$lang['AdminBilling.printqueue.page_title'] = 'Черга на друк рахунків';
$lang['AdminBilling.invoices.text_edit'] = 'Редагувати';
$lang['AdminBilling.invoices.applied_no_results'] = 'До цього інвойсу не застосовано жодних транзакцій.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Параметри';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Нанесено на';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Застосовано';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Тип платежу';
$lang['AdminBilling.transactions.applied_no_results'] = 'Ця операція не була застосована до жодного інвойсу.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Нанесено на';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.transactions.no_results'] = 'Транзакцій з таким статусом немає.';
$lang['AdminBilling.transactions.option_edit'] = 'Редагувати';
$lang['AdminBilling.transactions.category_returned'] = 'Повернуто';
$lang['AdminBilling.transactions.category_refunded'] = 'Відшкодовано';
$lang['AdminBilling.transactions.category_pending'] = 'На розгляді';
$lang['AdminBilling.transactions.category_error'] = 'Помилка.';
$lang['AdminBilling.transactions.category_voided'] = 'Анульовано';
$lang['AdminBilling.transactions.category_declined'] = 'Відхилено';
$lang['AdminBilling.transactions.category_approved'] = 'Затверджено';
$lang['AdminBilling.transactions.heading_options'] = 'Параметри';
$lang['AdminBilling.transactions.heading_date'] = 'Дата';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Посилання #';
$lang['AdminBilling.transactions.heading_number'] = 'Номер';
$lang['AdminBilling.transactions.heading_applied'] = 'Застосовано';
$lang['AdminBilling.transactions.heading_credit'] = 'В ролях';
$lang['AdminBilling.transactions.heading_amount'] = 'Сума';
$lang['AdminBilling.transactions.heading_type'] = 'Тип';
$lang['AdminBilling.transactions.heading_client'] = 'Клієнт №';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Транзакції';
$lang['AdminBilling.transactions.page_title'] = 'Білінгові операції';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Причина скасування: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Ця послуга не має реквізитів.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Надіслати';
$lang['AdminBilling.services.action.field_client'] = 'Клієнт:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push до клієнта';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Не скасовувати';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Конкретна дата';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Кінець терміну';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Скасування розкладу';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Сервісів з таким статусом немає.';
$lang['AdminBilling.services.text_never'] = 'Ніколи.';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Заплановано';
$lang['AdminBilling.services.category_in_review'] = 'В огляді';
$lang['AdminBilling.services.category_pending'] = 'На розгляді';
$lang['AdminBilling.services.category_suspended'] = 'Призупинено';
$lang['AdminBilling.services.category_canceled'] = 'Скасовано';
$lang['AdminBilling.services.category_active'] = 'Активний';
$lang['AdminBilling.services.confirm_delete'] = 'Ви впевнені, що хочете видалити цю послугу?';
$lang['AdminBilling.services.option_delete'] = 'Видалити';
$lang['AdminBilling.services.option_manage'] = 'Керувати';
$lang['AdminBilling.services.heading_options'] = 'Параметри';
$lang['AdminBilling.services.heading_datecanceled'] = 'Дата скасована';
$lang['AdminBilling.services.heading_datesuspended'] = 'Дата призупинена';
$lang['AdminBilling.services.heading_daterenews'] = 'Поновлення дати';
$lang['AdminBilling.services.heading_dateadded'] = 'Дата додавання';
$lang['AdminBilling.services.heading_term'] = 'Термін';
$lang['AdminBilling.services.heading_label'] = 'Етикетка';
$lang['AdminBilling.services.heading_package'] = 'Пакет';
$lang['AdminBilling.services.heading_client'] = 'Клієнт №';
$lang['AdminBilling.services.boxtitle_services'] = 'Послуги';
$lang['AdminBilling.services.page_title'] = 'Білінгові послуги';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'З цією ціною не пов\'язано жодних рахунків-фактур.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Вигляд';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Параметри';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Дата виставлення рахунку';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Оплачено';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Сума';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.quotations.no_results'] = 'Котирувань з таким статусом немає.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Ви впевнені, що хочете затвердити цю цитату?';
$lang['AdminBilling.quotations.option_approve'] = 'Затвердити';
$lang['AdminBilling.quotations.option_invoice'] = 'Створити рахунок-фактуру';
$lang['AdminBilling.quotations.option_view'] = 'Вигляд';
$lang['AdminBilling.quotations.option_edit'] = 'Редагувати';
$lang['AdminBilling.quotations.heading_options'] = 'Параметри';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Термін придатності';
$lang['AdminBilling.quotations.heading_date_created'] = 'Дата створення';
$lang['AdminBilling.quotations.heading_total'] = 'Сума';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Проміжний підсумок';
$lang['AdminBilling.quotations.heading_staff'] = 'Цитується';
$lang['AdminBilling.quotations.heading_title'] = 'Назва';
$lang['AdminBilling.quotations.heading_client'] = 'Клієнт №';
$lang['AdminBilling.quotations.heading_quotation'] = 'Цитата #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Цитати';
$lang['AdminBilling.quotations.page_title'] = 'Котирування рахунків';
$lang['AdminBilling.invoices.no_results'] = 'Інвойсів з таким статусом немає.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s разів';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s років';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s місяців';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s тижнів';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s днів';
$lang['AdminBilling.invoices.term_year'] = '%1$ рік';
$lang['AdminBilling.invoices.term_month'] = '%1$s місяць';
$lang['AdminBilling.invoices.term_week'] = '%1$ тиждень';
$lang['AdminBilling.invoices.term_day'] = '%1$ день';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s + податок';
$lang['AdminBilling.invoices.option_pay'] = 'Заплати';
$lang['AdminBilling.invoices.option_view'] = 'Вигляд';
$lang['AdminBilling.invoices.option_edit'] = 'Редагувати';
$lang['AdminBilling.invoices.category_recurring'] = 'Повторюється';
$lang['AdminBilling.invoices.category_pending'] = 'На розгляді';
$lang['AdminBilling.invoices.category_pastdue'] = 'Прострочена заборгованість';
$lang['AdminBilling.invoices.category_voided'] = 'Анульовано';
$lang['AdminBilling.invoices.category_closed'] = 'Закрито.';
$lang['AdminBilling.invoices.category_drafts'] = 'Чернетки';
$lang['AdminBilling.invoices.category_open'] = 'Відчинено';
$lang['AdminBilling.invoices.heading_count'] = 'Граф.';
$lang['AdminBilling.invoices.heading_duration'] = 'Тривалість';
$lang['AdminBilling.invoices.heading_term'] = 'Термін';
$lang['AdminBilling.invoices.heading_options'] = 'Параметри';
$lang['AdminBilling.invoices.heading_datedue'] = 'Дата сплати';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Дата виставлення рахунку';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Дата закрита';
$lang['AdminBilling.invoices.heading_due'] = 'Належить';
$lang['AdminBilling.invoices.heading_paid'] = 'Оплачено';
$lang['AdminBilling.invoices.heading_amount'] = 'Сума';
$lang['AdminBilling.invoices.heading_client'] = 'Клієнт №';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Повторювані #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Рахунок-фактура';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Рахунки-фактури';
$lang['AdminBilling.invoices.page_title'] = 'Виставлення рахунків-фактур';
$lang['AdminBilling.managewidgets.text_author'] = 'Автор:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Перетягніть віджети справа наліво, щоб додати їх до огляду рахунків, або зліва направо, щоб видалити.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Виберіть макет нижче, щоб налаштувати огляд рахунків.';
$lang['AdminBilling.index.action_batch'] = 'Товари, що очікують на партію';
$lang['AdminBilling.index.action_printqueue'] = 'Елементи, що очікують на друк';
$lang['AdminBilling.index.no_actions'] = 'На розгляді немає жодних питань щодо дій.';
$lang['AdminBilling.index.heading_actions'] = 'Пункти дій';
$lang['AdminBilling.index.customize_dashboard'] = 'Налаштувати огляд';
$lang['AdminBilling.index.manage_widgets'] = 'Керування віджетами';
$lang['AdminBilling.index.page_title'] = 'Огляд виставлення рахунків';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Запланована дата скасування не повинна бути в минулому.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Введена парольна фраза є невірною.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Не було відібрано жодного інвойсу.';
$lang['AdminBilling.!success.services_pushed'] = 'Обрані послуги були успішно продані новому клієнту.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Вибрані послуги більше не планується скасовувати.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Вибрані послуги були успішно скасовані за розкладом.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Вибрані інвойси позначені як надруковані.';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Причина відсторонення:';
$lang['AdminBilling.services.action.unsuspend'] = 'Розблокувати';
$lang['AdminBilling.services.action.suspend'] = 'Призупинити';
$lang['AdminBilling.!success.services_unsuspended'] = 'Відібрані сервіси були успішно відновлені.';
$lang['AdminBilling.!success.services_suspended'] = 'Вибрані сервіси були успішно призупинені.';
